@@ -4,12 +4,23 @@ from .mock_server_exception import MockServerException
 
 
 class MockServerRequestNotFoundException(MockServerException):
+    """
+    Exception when we found no expectation for a request
+    """
+
     def __init__(
         self,
         method: Optional[str],
         url: Optional[str],
         json_list: Optional[List[Dict[str, Any]]],
     ) -> None:
+        """
+        Exception when we found no expectation for a request
+
+        :param method: method of request
+        :param url: url of request
+        :param json_list: json body
+        """
         self.method: Optional[str] = method
         self.url: Optional[str] = url
         self.json_dict: Optional[List[Dict[str, Any]]] = json_list
